[java-identity-provider] branch master updated: IDP-1619 - Deprecate terms from classes and configuration
Scott Cantor
cantor.2 at osu.edu
Mon Jun 15 23:42:26 UTC 2020
This is an automated email from the git hooks/post-receive script.
scantor pushed a commit to branch master
in repository java-identity-provider.
View the commit online:
http://git.shibboleth.net/view/?p=java-identity-provider.git;a=commit;h=d72dfa6729eddbf7f96fc69c8bcd43c0d32a47bf
The following commit(s) were added to refs/heads/master by this push:
new d72dfa672 IDP-1619 - Deprecate terms from classes and configuration
d72dfa672 is described below
commit d72dfa6729eddbf7f96fc69c8bcd43c0d32a47bf
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Mon Jun 15 19:42:23 2020 -0400
IDP-1619 - Deprecate terms from classes and configuration
https://issues.shibboleth.net/jira/browse/IDP-1619
Adjust some comments.
---
.../impl/TransitionMultiFactorAuthentication.java | 4 ++--
.../resources/conf/intercept/profile-intercept.xml | 2 +-
.../system/conf/session-manager-system.xml | 2 +-
.../main/resources/system/conf/webflow-config.xml | 8 ++++----
.../system/flows/c14n/subject-c14n-flow.xml | 2 +-
.../flows/logout/logout-propagation-flow.xml | 2 +-
.../logic/impl/MessageSourceConsentFunction.java | 2 +-
.../idp/session/impl/StorageBackedIdPSession.java | 24 +++++++++++-----------
.../session/impl/StorageBackedSessionManager.java | 16 +++++++--------
9 files changed, 31 insertions(+), 31 deletions(-)
diff --git a/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/TransitionMultiFactorAuthentication.java b/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/TransitionMultiFactorAuthentication.java
index d09247faf..cb1b87659 100644
--- a/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/TransitionMultiFactorAuthentication.java
+++ b/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/TransitionMultiFactorAuthentication.java
@@ -42,8 +42,8 @@ import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
- * An authentication action that acts as the master evaluation step regulating execution
- * of transitions between MFA stages.
+ * An authentication action that acts as the driver regulating execution of transitions
+ * between MFA stages.
*
* <p>This is the heart of the MFA processing sequence, and runs after the
* {@link MultiFactorAuthenticationContext} has been populated. It uses the current/previous
diff --git a/idp-conf/src/main/resources/conf/intercept/profile-intercept.xml b/idp-conf/src/main/resources/conf/intercept/profile-intercept.xml
index f086cfaab..736e7bf6e 100644
--- a/idp-conf/src/main/resources/conf/intercept/profile-intercept.xml
+++ b/idp-conf/src/main/resources/conf/intercept/profile-intercept.xml
@@ -13,7 +13,7 @@
default-destroy-method="destroy">
<!--
- Intercept flows are used at various injection points to modify processing. This is the master list
+ Intercept flows are used at various injection points to modify processing. This is the overall list
of flows available that provide interesting features to deployers, but flows are actually enabled by
specifying them in various profile configuration beans via relying-party.xml
diff --git a/idp-conf/src/main/resources/system/conf/session-manager-system.xml b/idp-conf/src/main/resources/system/conf/session-manager-system.xml
index 2afbfe220..144afa6cc 100644
--- a/idp-conf/src/main/resources/system/conf/session-manager-system.xml
+++ b/idp-conf/src/main/resources/system/conf/session-manager-system.xml
@@ -84,7 +84,7 @@
<bean id="logoutprop/saml2" class="net.shibboleth.idp.session.LogoutPropagationFlowDescriptor"
c:_0="#{ T(net.shibboleth.idp.saml.session.SAML2SPSession) }" />
- <!-- Selector function used in logout-propagation UI and logout-propagation master flow -->
+ <!-- Selector function used in logout-propagation UI and logout-propagation driver flow -->
<bean id="shibboleth.LogoutPropagationFlowSelector"
class="net.shibboleth.idp.session.logic.LogoutPropagationFlowDescriptorSelector"
diff --git a/idp-conf/src/main/resources/system/conf/webflow-config.xml b/idp-conf/src/main/resources/system/conf/webflow-config.xml
index daec68725..01b8c4976 100644
--- a/idp-conf/src/main/resources/system/conf/webflow-config.xml
+++ b/idp-conf/src/main/resources/system/conf/webflow-config.xml
@@ -35,7 +35,7 @@
<!-- Proprietary logout flow. -->
<entry key="Logout" value="../system/flows/logout/logout-flow.xml" />
- <!-- Logout propagation master flow. -->
+ <!-- Logout propagation driver flow. -->
<entry key="PropagateLogout" value="../system/flows/logout/logout-propagation-flow.xml" />
<!-- Logout propagation delegate flows. -->
@@ -69,7 +69,7 @@
<!-- Liberty IDWSF SSOS flow (for SAML 2 delegation) -->
<entry key="IDWSF/SSOS" value="../system/flows/saml/saml2/idwsf-ssos-flow.xml" />
- <!-- Master flow for authentication. -->
+ <!-- Main flow for authentication. -->
<entry key="authn.events" value="../conf/authn/authn-events-flow.xml" />
<entry key="authn.abstract" value="../system/flows/authn/authn-abstract-flow.xml" />
<entry key="authn" value="../system/flows/authn/authn-flow.xml" />
@@ -91,7 +91,7 @@
<!-- One-off flow for discovery. -->
<entry key="authn/Discovery" value="../system/flows/authn/discovery-flow.xml" />
- <!-- Master flow for subject c14n. -->
+ <!-- Main flow for subject c14n. -->
<entry key="c14n.events" value="../conf/c14n/subject-c14n-events-flow.xml" />
<entry key="c14n.abstract" value="../system/flows/c14n/subject-c14n-abstract-flow.xml" />
<entry key="c14n" value="../system/flows/c14n/subject-c14n-flow.xml" />
@@ -116,7 +116,7 @@
<entry key="c14n/SAML1Transform" value="../system/flows/c14n/subject-c14n-saml-default-flow.xml" />
<entry key="c14n/LegacyPrincipalConnector" value="../system/flows/c14n/subject-c14n-saml-default-flow.xml" />
- <!-- Master intercept flow. -->
+ <!-- Main intercept flow. -->
<entry key="intercept.events" value="../conf/intercept/intercept-events-flow.xml" />
<entry key="intercept.abstract" value="../system/flows/intercept/intercept-abstract-flow.xml" />
<entry key="intercept" value="../system/flows/intercept/intercept-flow.xml" />
diff --git a/idp-conf/src/main/resources/system/flows/c14n/subject-c14n-flow.xml b/idp-conf/src/main/resources/system/flows/c14n/subject-c14n-flow.xml
index cdbf469eb..029c62e66 100644
--- a/idp-conf/src/main/resources/system/flows/c14n/subject-c14n-flow.xml
+++ b/idp-conf/src/main/resources/system/flows/c14n/subject-c14n-flow.xml
@@ -4,7 +4,7 @@
parent="c14n.abstract">
<!--
- This is the master SubjectCanonicalization subflow. It handles selection of
+ This is the main SubjectCanonicalization subflow. It handles selection of
c14n subflows before returning control to the calling flow.
-->
diff --git a/idp-conf/src/main/resources/system/flows/logout/logout-propagation-flow.xml b/idp-conf/src/main/resources/system/flows/logout/logout-propagation-flow.xml
index 117055e27..73d4abe95 100644
--- a/idp-conf/src/main/resources/system/flows/logout/logout-propagation-flow.xml
+++ b/idp-conf/src/main/resources/system/flows/logout/logout-propagation-flow.xml
@@ -2,7 +2,7 @@
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xsi:schemaLocation="http://www.springframework.org/schema/webflow http://www.springframework.org/schema/webflow/spring-webflow.xsd">
- <!-- Master flow to propagate a logout of an SPSession by determining a subflow to run based on the type. -->
+ <!-- Main flow to propagate a logout of an SPSession by determining a subflow to run based on the type. -->
<action-state id="InitializeProfileRequestContext">
<evaluate expression="InitializeProfileRequestContext" />
diff --git a/idp-consent-impl/src/main/java/net/shibboleth/idp/consent/logic/impl/MessageSourceConsentFunction.java b/idp-consent-impl/src/main/java/net/shibboleth/idp/consent/logic/impl/MessageSourceConsentFunction.java
index 008661069..50a915513 100644
--- a/idp-consent-impl/src/main/java/net/shibboleth/idp/consent/logic/impl/MessageSourceConsentFunction.java
+++ b/idp-consent-impl/src/main/java/net/shibboleth/idp/consent/logic/impl/MessageSourceConsentFunction.java
@@ -43,7 +43,7 @@ import org.springframework.context.NoSuchMessageException;
* Function that returns a consent object whose id and value are resolved from a lookup function
* and {@link MessageSource}.
*
- * <p>The lookup function's return value is a master key, mapped via the {@link MessageSource} to an ID.
+ * <p>The lookup function's return value is a key, mapped via the {@link MessageSource} to an ID.
* A suffix is attached to the ID to obtain the message key of the value.</p>
*/
public class MessageSourceConsentFunction extends AbstractInitializableComponent
diff --git a/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedIdPSession.java b/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedIdPSession.java
index 5433b8eb7..73d53d102 100644
--- a/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedIdPSession.java
+++ b/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedIdPSession.java
@@ -85,17 +85,17 @@ public class StorageBackedIdPSession extends AbstractIdPSession {
final Instant exp =
instant.plus(sessionManager.getSessionTimeout()).plus(sessionManager.getSessionSlop());
- log.debug("Updating expiration of master record for session {} to {}", getId(), exp);
+ log.debug("Updating expiration of primary record for session {} to {}", getId(), exp);
try {
sessionManager.getStorageService().updateExpiration(
- getId(), StorageBackedSessionManager.SESSION_MASTER_KEY, exp.toEpochMilli());
+ getId(), StorageBackedSessionManager.SESSION_PRIMARY_KEY, exp.toEpochMilli());
super.setLastActivityInstant(instant);
} catch (final IOException e) {
if (!sessionManager.isMaskStorageFailure()) {
throw new SessionException("Exception updating expiration of session record", e);
}
- log.error("Exception updating expiration of master record for session {}", getId(), e);
+ log.error("Exception updating expiration of primary record for session {}", getId(), e);
}
}
@@ -159,7 +159,7 @@ public class StorageBackedIdPSession extends AbstractIdPSession {
if (!sessionManager.isMaskStorageFailure()) {
throw new SessionException("Exception updating address binding of session record", e);
}
- log.error("Exception updating address binding of master record for session {}", getId(), e);
+ log.error("Exception updating address binding of primary record for session {}", getId(), e);
}
}
@@ -233,7 +233,7 @@ public class StorageBackedIdPSession extends AbstractIdPSession {
}
final AuthenticationResult prev = super.addAuthenticationResult(result);
if (prev == null) {
// If no previous record, the add operation changed the master record, requiring an update.
int attempts = 10;
boolean success = writeToStorage();
while (!success && attempts-- > 0) {
@@ -300,7 +300,7 @@ public class StorageBackedIdPSession extends AbstractIdPSession {
result.getAuthenticationFlowId(), e);
}
- // Try and update the master record with the updated flow list.
+ // Try and update the primary record with the updated flow list.
try {
int attempts = 10;
boolean success = writeToStorage();
@@ -413,7 +413,7 @@ public class StorageBackedIdPSession extends AbstractIdPSession {
}
final SPSession prev = super.addSPSession(spSession);
if (prev == null) {
// If no previous record, the add operation changed the master record, requiring an update.
int attempts = 10;
boolean success = writeToStorage();
while (!success && attempts-- > 0) {
@@ -462,7 +462,7 @@ public class StorageBackedIdPSession extends AbstractIdPSession {
}
}
- // Try and update the master record with the updated service session list.
+ // Try and update the primary record with the updated service session list.
try {
int attempts = 10;
boolean success = writeToStorage();
@@ -728,7 +728,7 @@ public class StorageBackedIdPSession extends AbstractIdPSession {
}
/**
* Update the master session record based on the current contents of this object.
*
* @return true iff the update succeeds, false iff a version mismatch resulted in overwrite of this object
* @throws IOException if an error occurs trying to perform an update
@@ -738,7 +738,7 @@ public class StorageBackedIdPSession extends AbstractIdPSession {
final Instant exp = getLastActivityInstant().plus(sessionManager.getSessionTimeout()).plus(
sessionManager.getSessionSlop());
final Long ver = sessionManager.getStorageService().updateWithVersion(version, getId(),
- StorageBackedSessionManager.SESSION_MASTER_KEY, this, sessionManager.getStorageSerializer(),
+ StorageBackedSessionManager.SESSION_PRIMARY_KEY, this, sessionManager.getStorageSerializer(),
exp.toEpochMilli());
if (ver == null) {
log.error("Record for session {} has disappeared from backing store", getId());
@@ -750,13 +750,13 @@ public class StorageBackedIdPSession extends AbstractIdPSession {
// The record has changed underneath. We need to deserialize the session back into the
// same object by passing ourselves as the target object to a new serializer instance.
final StorageRecord<StorageBackedIdPSession> record =
- sessionManager.getStorageService().read(getId(), StorageBackedSessionManager.SESSION_MASTER_KEY);
+ sessionManager.getStorageService().read(getId(), StorageBackedSessionManager.SESSION_PRIMARY_KEY);
if (record == null) {
log.error("Record for session {} has disappeared from backing store", getId());
throw new IOException("Unable to update session, record disappeared");
}
record.getValue(new StorageBackedIdPSessionSerializer(sessionManager, this),
- getId(), StorageBackedSessionManager.SESSION_MASTER_KEY);
+ getId(), StorageBackedSessionManager.SESSION_PRIMARY_KEY);
return false;
}
}
@@ -233,7 +233,7 @@ public class StorageBackedIdPSession extends AbstractIdPSession {
final AuthenticationResult prev = super.addAuthenticationResult(result);
if (prev == null) {
- // If no previous record, the add operation changed the master record, requiring an update.
+ // If no previous record, the add operation changed the primary record, requiring an update.
int attempts = 10;
boolean success = writeToStorage();
@@ -413,7 +413,7 @@ public class StorageBackedIdPSession extends AbstractIdPSession {
final SPSession prev = super.addSPSession(spSession);
if (prev == null) {
- // If no previous record, the add operation changed the master record, requiring an update.
+ // If no previous record, the add operation changed the primary record, requiring an update.
int attempts = 10;
boolean success = writeToStorage();
@@ -728,7 +728,7 @@ public class StorageBackedIdPSession extends AbstractIdPSession {
}
/**
- * Update the master session record based on the current contents of this object.
+ * Update the primary session record based on the current contents of this object.
*
* @return true iff the update succeeds, false iff a version mismatch resulted in overwrite of this object
diff --git a/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedSessionManager.java b/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedSessionManager.java
index 4b39c7828..d30758e20 100644
--- a/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedSessionManager.java
+++ b/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedSessionManager.java
@@ -70,7 +70,7 @@ import com.google.common.collect.ImmutableList;
* {@link StorageService} for persistence and lifecycle management of data.
*
* <p>
- * The storage layout here is to store most data in a context named for the session ID. Within that context, the master
+ * The storage layout here is to store most data in a context named for the session ID. Within that context, the
* {@link IdPSession} record lives under a key called "_session", with an expiration based on the session timeout value
* plus a configurable amount of "slop" to prevent premature disappearance in case of logout.
* </p>
@@ -86,8 +86,8 @@ import com.google.common.collect.ImmutableList;
* </p>
*
* <p>
- * For cross-referencing, lists of flow and service IDs are tracked within the master "_session" record, so adding
- * either requires an update to the master record plus the creation of a new one. Post-creation, there are no updates to
+ * For cross-referencing, lists of flow and service IDs are tracked within the "_session" record, so adding
+ * either requires an update to that record plus the creation of a new one. Post-creation, there are no updates to
* the AuthenticationResult or SPSession records, but the expiration of the result records can be updated to reflect
* activity updates.
* </p>
@@ -109,8 +109,8 @@ import com.google.common.collect.ImmutableList;
public class StorageBackedSessionManager extends AbstractIdentifiableInitializableComponent implements SessionManager,
SessionResolver {
- /** Storage key of master session records. */
- @Nonnull @NotEmpty public static final String SESSION_MASTER_KEY = "_session";
+ /** Storage key of primary session records. */
+ @Nonnull @NotEmpty public static final String SESSION_PRIMARY_KEY = "_session";
/** Default cookie name for session tracking. */
@Nonnull @NotEmpty protected static final String DEFAULT_COOKIE_NAME = "shib_idp_session";
@@ -535,7 +535,7 @@ public class StorageBackedSessionManager extends AbstractIdentifiableInitializab
newSession.doBindToAddress(remoteAddr);
try {
- if (!storageService.create(sessionId, SESSION_MASTER_KEY, newSession, serializer,
+ if (!storageService.create(sessionId, SESSION_PRIMARY_KEY, newSession, serializer,
newSession.getCreationInstant().plus(sessionTimeout).plus(sessionSlop).toEpochMilli())) {
throw new SessionException("A duplicate session ID was generated, unable to create session");
}
@@ -812,9 +812,9 @@ public class StorageBackedSessionManager extends AbstractIdentifiableInitializab
try {
final StorageRecord<StorageBackedIdPSession> sessionRecord =
- storageService.read(sessionId, SESSION_MASTER_KEY);
+ storageService.read(sessionId, SESSION_PRIMARY_KEY);
if (sessionRecord != null) {
- return sessionRecord.getValue(serializer, sessionId, SESSION_MASTER_KEY);
+ return sessionRecord.getValue(serializer, sessionId, SESSION_PRIMARY_KEY);
}
log.debug("Primary lookup failed for session ID {}", sessionId);
} catch (final IOException e) {
--
To stop receiving notification emails like this one, please contact
the administrator of this repository.
More information about the commits
mailing list